/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Jetable mail extension
 *
 * The Initial Developer of the Original Code is Nicolas Moreau
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * Original Author: Nicolas Moreau (nmoreau@stricto-sensu.net)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/**
 * Contact jetable.org website to generate a jetable email
 */
function generateJetableMail(){

	var mail = document.getElementById('jetable-email').value;
	var duree = document.getElementById('jetable-duree').value;
	
	var bundle = document.getElementById('jetable-bundle');
	var board = document.getElementById('jetable-board');
	
	board.value = '';
	
	if(mail.length>0 && seemsMail(mail)){
		busyUI();
		updatePreferences(mail);
			
		var objHTTP;
		objHTTP = new XMLHttpRequest();
		objHTTP.open("POST",'http://jetable.org/plugins/getmail.php',false);
		objHTTP.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
		objHTTP.send('time='+duree+'&email='+mail);
		var result=objHTTP.responseText;
		
		if(result == parseInt(result)){ //an error occured
			cleanUI();
			board.value = bundle.getString('jetablemail-popup-error'+result);	
		}
		else{
			insertEmail(result);
			window.close();
		}
	}
}

/**
 * On load, fill the email menulist with emails saved in preferences
 */
function builtEmailList(){

	var prefs = Components.classes["@mozilla.org/preferences-service;1"].
		getService(Components.interfaces.nsIPrefBranch);
		
	var mail,i,item;
	var list = document.getElementById('jetable-email');
	var popup = list.menupopup;
	
	for(i=1;i<6;i++){
		try { 
			mail=prefs.getCharPref("jetable.email."+i);
		
			if(mail.length>0)
				list.appendItem(mail);
		}
		catch(e){}
	}
	
	if(popup.getElementsByTagName('menuitem').length > 0)
		list.selectedItem = popup.firstChild;	
}

/**
 * Insert a mail in the focused element on the HTML page
 * @param  [string]mail The mail to insert
 */
function insertEmail(mail){
	var elt = window.arguments[0];
	if(elt.type == 'textarea'){
		if(elt.textLength == elt.selectionStart)
			elt.value = elt.value + mail;
		else
			elt.value = elt.value.substring(0, elt.selectionStart) + mail + elt.value.substring(elt.selectionEnd, elt.textLength);
	}
	else{ // input
		elt.value = mail;
	}
}

/**
 * Apply the UI default style
 */ 
function cleanUI(){
	var board = document.getElementById('jetable-board');
	board.value = '';
	document.getElementById('jetable-go').disabled = false;
	document.getElementById('jetable-email').disabled = false;
	document.getElementById('jetable-duree').disabled = false;
}

/**
 * Apply the UI 'busy' style
 */ 
function busyUI(){
	document.getElementById('jetable-go').disabled = true;
	document.getElementById('jetable-email').disabled = true;
	document.getElementById('jetable-duree').disabled = true;
	
	var bundle = document.getElementById('jetable-bundle');
	var board = document.getElementById('jetable-board');
	
	board.value = bundle.getString('jetablemail-popup-connexion');
}

/**
 * Check if preferences are full, and if not, save a new mail in it
 * @param  [string]mail The mail which may be saved in preferences
 */
function updatePreferences(mail){

	var prefs = Components.classes["@mozilla.org/preferences-service;1"].
		getService(Components.interfaces.nsIPrefBranch);
		
	var i,freepref,registeredmail;
	var prefmails=new Array();
	
	for(i=1;i<6;i++){
		try{
			registeredmail=prefs.getCharPref("jetable.email."+i);
			
		 	if(registeredmail.length > 0)
				prefmails.push(registeredmail);
			else
				if(!freepref)
					freepref=i;
		}
		catch(e){}
	}
	
	if(freepref){
		for(i=0;i<prefmails.length;i++)
			if(prefmails[i]==mail)
				return 0;
				
		prefs.setCharPref("jetable.email."+freepref,mail);
	}
}

/**
 * Test if a string seems to be a mail (poor verification)
 * @param  [string]mail The mail to test
 */
function seemsMail(mail){
	var filter=/^[^@]+@([^@]+\.[^@]+)$/;
	return (filter.test(mail) && RegExp.$1.toLowerCase()!="jetable.org");
}